==> kwy-wechatapi-1.4.2-725ba1.tar: test/OpenWxTest.php <==
<?php
/**
 * Created by PhpStorm.
 * User: roc
 * Date: 2019/5/28
 * Time: 15:05
 */

namespace kwy\wechatapi\test;

use kwy\union\up\pay\Pay;
use kwy\wechatapi\openwx\common\WxBizMsgCrypt;
use kwy\wechatapi\openwx\Component;
use kwy\wechatapi\openwx\WxApp;
use kwy\wechatapi\openwx\WxException;
use PHPUnit\Framework\TestCase;

/**
 * 微信开放平台demo
 * Class OpenWxTest
 * @package kwy\wechatapi\test
 */
class OpenWxTest extends TestCase{

    private $appid = "wx0f8989ab60d9588d";
    private $token = "weixin";
    private $key = "F5g83hVjUpPnay3ztw1MdibdszD0tuxeHXnMVKNRk97";
    private $app_secret = "582fc1ce5f5e12e6284316f9b320e075";
    private $componetAccessToken = "28_MWNC8loROE3TFaoMAkfh7bT55e_kTv8pD3N2gVwpUwLNAOcx7Y3zvLtg6zv4sHnd8rIUzeGDUbdE6Ia1Kczc8YhJSOBUK7mutsKWfhBixGRZ1dSVpa-IUwD3lfM2iM4_AfUtiSt7t8RlY2a5QZHhACAVEM";


    /**
     * 统一下单
     * @author roc
     * @datetime:2019/12/12 13:43
     */
    public function t2estGetComponentVerifyTicket(){
        $obj = new WxBizMsgCrypt();

        $obj->setAppId($this->appid)->setToken($this->token)
            ->setEncodingAesKey($this->key);

        $postData = "<xml>
    <AppId><![CDATA[wx0f8989ab60d9588d]]></AppId>
    <Encrypt><![CDATA[sRxX+5ETg/DehbhLe280O/Jrn3E0swfj5wf5gS0pEsZbnrHmY+TX9DiTzZS/CubFKurTfUpH/qTIFHnvyQ+U5qZ30T+qPkKZt88ydh4NapIDCN46VUBkqzB8V05OP73Cy6s/NqpV2MbWE6V//OW/ZFdUM8gdk3xIUzfuaQDnh8G5AqXcxieqaCsW/LpnJj7FpWKKTSlA+0prxPZGRu7DJ61I+VqpY1enWVDKhATVqd58eX+z7FqewiNcmZwlWpzoUDsbUov5k2cfMwb55pf94VFCpOJAvCdKDotqocZY2F6N+srFqCQguVqCXLMSwr+bbNnDjdVfsFDwtipdpvyAzIT4/WWmolN8XUdgNisR73rHkwwzNbAX83gABSAuAyJzY08N1G6VMMEs1JrAnHBqZj/GTKmC5tTc23sEHFkei291iHtOClR8Zjc6vVPcj8Yanrs2BX1fpV0lb95fbn4cDQ==]]></Encrypt>
</xml>";
        $msgSignature = "d2d80396a6c55f019e80dd935d0e0afb9d9483f9";
        $timestamp = "1576836846";
        $nonce = "305651070";

        try{
            /**
             * InfoType字段注释：
             * component_verify_ticket
             * authorized：授权成功通知
             * unauthorized：取消授权通知
             * updateauthorized：授权更新通知
             *
             */
            /**
             * array (
            'AppId' => 'wx0f8989ab60d9588d',
            'CreateTime' => '1576822342',
            'InfoType' => 'component_verify_ticket',
            'ComponentVerifyTicket' => 'ticket@@@y2ee_3Fm5SL-gEyFElCMeuUnNGwlBflPldoG83zYvo4iQZcNaBYOvHs9hfHcLE5tztcD1pM0ntmubZXWBKYb4g',
            )

             */
            $result = $obj->decryptMsg($msgSignature, $timestamp, $nonce, $postData);
//            echo $result."\n";
            echo var_export($result)."\n";
            $componentVerifyTicket = $result["ComponentVerifyTicket"];
            echo "=======================================\n";
            echo $result["ComponentVerifyTicket"]."\n";
//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);
            return ["ComponentVerifyTicket"=>$componentVerifyTicket];
        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
            return ["ComponentVerifyTicket"=>'a'];
        }

    }

    /**
     * 获取令牌
     * @author roc
     * @datetime:2019/12/20 18:24
     * @depends testGetComponentVerifyTicket
     * PHPUnit可以实现测试方法的依赖关系，也就是说，一个测试方法的参数的内容和是否会运行依赖于另外一个测试方法结果，依赖关系通过注释@depends来定义.这个特性一般用于检查代码的逻辑过程,一个逻辑的执行前提是另外一个逻辑的执行结果.下面来看代码例子:
     * @param $data
     * @return array
     */
    public function t2estGetApiComponentToken($data){
        echo "abcdefghijklmnopqrstuvwxyz==================\n";
        echo var_export($data,true)."\n";
        echo "abcdefghijklmnopqrstuvwxyz==================\n";
        $obj = new Component();
        $componentVerifyTicket = $data["ComponentVerifyTicket"];
        echo "========testGetApiComponentToken====\n";
        echo $componentVerifyTicket."\n";

        echo $this->appid."\n";
        try{
            $obj->setProxy("127.0.0.1:8888");
            $result = $obj->setComponetAppid($this->appid)
                ->setComponentVerifyTicket($componentVerifyTicket)
                ->setComponetAppSecret($this->app_secret)
                ->getApiComponentToken();
            echo "=======================================\n";
            echo var_export($result)."\n";
            echo $result["component_access_token"]."\n";
//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);

            return ["component_access_token"=>$result["component_access_token"]];
        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
        }
    }

    /**
     * 获取预授权码
     * @author roc
     * @datetime:2019/12/19 17:09
     */
    public function t2estGetPreAuthCode(){
        $obj = new Component();


        echo $this->appid."\n";
        try{
            $obj->setProxy("127.0.0.1:8888");
            $result = $obj->setComponetAppid($this->appid)->setComponetAccessToken($this->componetAccessToken)
                ->getPreAuthCode();
            echo "=======================================\n";
            echo var_export($result)."\n";
//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);

        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
        }
    }

    /**
     * 使用授权码获取授权信息
     * 当用户在第三方平台授权页中完成授权流程后，第三方平台开发者可以在回调 URI 中通过 URL 参数获取授权码。
     * 使用以下接口可以换取公众号/小程序的授权信息。
     * 建议保存授权信息中的刷新令牌（authorizer_refresh_token）
     * @author roc
     * @datetime:2019/12/19 17:09
     */
    public function t2estApiQueryAuth(){
        $obj = new Component();

//        $url = "https://test.kwyapi.ke51.com/index/Y/testIndexCallBack?auth_code=&expires_in=3600";
        $auth_code = "queryauthcode@@@fj8Q0ik7agxkXuy1lvhVk-P3zOEjXfLk6LSd46Cl3F2WSMtp8k1wsEFOMXChzjNpRTkbY7buwXcWVp3lV-ANWA";
        $expires_in = "3600";
        $authorization_code = $auth_code;

        echo $this->appid."\n";
        try{
            $obj->setProxy("127.0.0.1:8888");
            $result = $obj->setComponetAppid($this->appid)->setComponetAccessToken($this->componetAccessToken)
                ->apiQueryAuth($authorization_code);
            echo "=======================================\n";
            echo var_export($result)."\n";
            $authorizer_appid = $result["authorizer_appid"];    //授权方 appid
            $authorizer_access_token = $result["authorizer_access_token"];    //接口调用令牌（在授权的公众号/小程序具备API权限时，才有此返回值）
            $expires_in = $result["expires_in"];    //authorizer_access_token的有效期（在授权的公众号/小程序具备API权限时，才有此返回值），单位：秒
            $authorizer_refresh_token = $result["authorizer_refresh_token"];    //刷新令牌（在授权的公众号具备API权限时，才有此返回值），刷新令牌主要用于第三方平台获取和刷新已授权用户的 authorizer_access_token。一旦丢失，只能让用户重新授权，才能再次拿到新的刷新令牌。用户重新授权后，之前的刷新令牌会失效
            $func_info = $result["func_info"];    //授权给开发者的权限集列表


//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);

        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
        }
    }

    /**
     * 获取授权方的帐号基本信息
     * @author roc
     * PHPUnit可以实现测试方法的依赖关系，也就是说，一个测试方法的参数的内容和是否会运行依赖于另外一个测试方法结果，依赖关系通过注释@depends来定义.这个特性一般用于检查代码的逻辑过程,一个逻辑的执行前提是另外一个逻辑的执行结果.下面来看代码例子:
     * @datetime:2019/12/20 12:15
     */
    public function testApiGetAuthorizerInfo(){
        $obj = new Component();

//        $url = "https://test.kwyapi.ke51.com/index/Y/testIndexCallBack?auth_code=&expires_in=3600";
        $authorizer_appid = "wx7a03580e7437b28f";
        $authorizer_appid = "wxcf8fdb66f0b906b9";

        try{
            $obj->setProxy("127.0.0.1:8888");
            $result = $obj->setComponetAppid($this->appid)
                ->setComponetAccessToken($this->componetAccessToken)
                ->apiGetAuthorizerInfo($authorizer_appid);
            echo "=======================================\n";
            echo var_export($result)."\n";


//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);
            return ["authorizer_refresh_token"=>$result["authorization_info"]["authorizer_refresh_token"]];

        }catch (WxException $wxE){
            echo "wx_error==============:".$wxE->getMessage().",file:".$wxE->getFile().",line:".$wxE->getLine().",wx_code:".$wxE->getWxErrCode()."====\n";
        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
        }
    }

    /**
     * 获取授权方的帐号基本信息
     * @author roc
     * @depends testApiGetAuthorizerInfo
     * PHPUnit可以实现测试方法的依赖关系，也就是说，一个测试方法的参数的内容和是否会运行依赖于另外一个测试方法结果，依赖关系通过注释@depends来定义.这个特性一般用于检查代码的逻辑过程,一个逻辑的执行前提是另外一个逻辑的执行结果.下面来看代码例子:
     * @param $data
     * @datetime:2019/12/20 12:15
     */
    public function t2estApiAuthorizerToken($data){
        $obj = new Component();

//        $url = "https://test.kwyapi.ke51.com/index/Y/testIndexCallBack?auth_code=&expires_in=3600";
        $authorizer_appid = "wx7a03580e7437b28f";
        $authorizer_refresh_token = $data["authorizer_refresh_token"];

        echo $authorizer_refresh_token."\n";
        try{
            $obj->setProxy("127.0.0.1:8888");
            $result = $obj->setComponetAppid($this->appid)
                ->setComponetAccessToken($this->componetAccessToken)
                ->apiAuthorizerToken($authorizer_appid,$authorizer_refresh_token);
            echo "=======================================\n";
            echo var_export($result)."\n";

            echo $result["authorizer_access_token"]."\n";

//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);

        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
        }
    }

    public function t2est(){
        $auth_type = "3";
        $component_appid = "wx0f8989ab60d9588d";
        $pre_auth_code = "preauthcode@@@d2O6Ayt5YXxJmho8WT0jdq-EqCDlNib_yCzzHaTCcxmTZE9ts0Ssn6AXkz2Hvc6z";
        $redirect_uri = "https://test.kwyapi.ke51.com/index/Y/testIndexCallBack";
        $url = "https://mp.weixin.qq.com/cgi-bin/componentloginpage?component_appid={$component_appid}&pre_auth_code={$pre_auth_code}&redirect_uri={$redirect_uri}&auth_type={$auth_type}";
//        $url = "https://mp.weixin.qq.com/safe/bindcomponent?action=bindcomponent&auth_type={$auth_type}&no_scan=1&component_appid={$component_appid}&pre_auth_code={$pre_auth_code}&redirect_uri={$redirect_uri}&auth_type={$auth_type}&biz_appid=xxxx#wechat_redirect";
        echo urlencode($url);
//        echo $url;
    }
}

==> kwy-wechatapi-1.6.6-807688.tar: test/OpenWxTest.php <==
<?php
/**
 * Created by PhpStorm.
 * User: roc
 * Date: 2019/5/28
 * Time: 15:05
 */

namespace kwy\wechatapi\test;

use kwy\union\up\pay\Pay;
use kwy\wechatapi\common\WXBizDataCrypt;
use kwy\wechatapi\openwx\common\WxBizMsgCrypt;
use kwy\wechatapi\openwx\Component;
use kwy\wechatapi\openwx\WxApp;
use kwy\wechatapi\openwx\WxException;
use PHPUnit\Framework\TestCase;

/**
 * 微信开放平台demo
 * Class OpenWxTest
 * @package kwy\wechatapi\test
 */
class OpenWxTest extends TestCase{

    private $appid = "wx0f8989ab60d9588d";
    private $token = "weixin";
    private $key = "F5g83hVjUpPnay3ztw1MdibdszD0tuxeHXnMVKNRk97";
    private $app_secret = "582fc1ce5f5e12e6284316f9b320e075";
    private $componetAccessToken = "30_4oNGpqIv2fvMVVGffUH_EWwQ4I0fr15xjpl1aakh2A9Uy0oG1JLHPhYuKV4YKa3E4U_Q_PpeUOTbnMfuAE3NpjBOn9i8H669Nn1JisdM5qpsS9FVU6z_Zi0tZ7NVQC_oyT0aKjGSFxq83tz0MZOeAHAQDS";


    /**
     * 统一下单
     * @author roc
     * @datetime:2019/12/12 13:43
     */
    public function t2estGetComponentVerifyTicket(){
        $obj = new WxBizMsgCrypt();

        $obj->setAppId($this->appid)->setToken($this->token)
            ->setEncodingAesKey($this->key);

        $postData = "<xml>
    <AppId><![CDATA[wx0f8989ab60d9588d]]></AppId>
    <Encrypt><![CDATA[sRxX+5ETg/DehbhLe280O/Jrn3E0swfj5wf5gS0pEsZbnrHmY+TX9DiTzZS/CubFKurTfUpH/qTIFHnvyQ+U5qZ30T+qPkKZt88ydh4NapIDCN46VUBkqzB8V05OP73Cy6s/NqpV2MbWE6V//OW/ZFdUM8gdk3xIUzfuaQDnh8G5AqXcxieqaCsW/LpnJj7FpWKKTSlA+0prxPZGRu7DJ61I+VqpY1enWVDKhATVqd58eX+z7FqewiNcmZwlWpzoUDsbUov5k2cfMwb55pf94VFCpOJAvCdKDotqocZY2F6N+srFqCQguVqCXLMSwr+bbNnDjdVfsFDwtipdpvyAzIT4/WWmolN8XUdgNisR73rHkwwzNbAX83gABSAuAyJzY08N1G6VMMEs1JrAnHBqZj/GTKmC5tTc23sEHFkei291iHtOClR8Zjc6vVPcj8Yanrs2BX1fpV0lb95fbn4cDQ==]]></Encrypt>
</xml>";
        $msgSignature = "d2d80396a6c55f019e80dd935d0e0afb9d9483f9";
        $timestamp = "1576836846";
        $nonce = "305651070";

        try{
            /**
             * InfoType字段注释：
             * component_verify_ticket
             * authorized：授权成功通知
             * unauthorized：取消授权通知
             * updateauthorized：授权更新通知
             *
             */
            /**
             * array (
            'AppId' => 'wx0f8989ab60d9588d',
            'CreateTime' => '1576822342',
            'InfoType' => 'component_verify_ticket',
            'ComponentVerifyTicket' => 'ticket@@@y2ee_3Fm5SL-gEyFElCMeuUnNGwlBflPldoG83zYvo4iQZcNaBYOvHs9hfHcLE5tztcD1pM0ntmubZXWBKYb4g',
            )

             */
            $result = $obj->decryptMsg($msgSignature, $timestamp, $nonce, $postData);
//            echo $result."\n";
            echo var_export($result)."\n";
            $componentVerifyTicket = $result["ComponentVerifyTicket"];
            echo "=======================================\n";
            echo $result["ComponentVerifyTicket"]."\n";
//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);
            return ["ComponentVerifyTicket"=>$componentVerifyTicket];
        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
            return ["ComponentVerifyTicket"=>'a'];
        }

    }

    /**
     * 获取令牌
     * @author roc
     * @datetime:2019/12/20 18:24
     * @depends testGetComponentVerifyTicket
     * PHPUnit可以实现测试方法的依赖关系，也就是说，一个测试方法的参数的内容和是否会运行依赖于另外一个测试方法结果，依赖关系通过注释@depends来定义.这个特性一般用于检查代码的逻辑过程,一个逻辑的执行前提是另外一个逻辑的执行结果.下面来看代码例子:
     * @param $data
     * @return array
     */
    public function t2estGetApiComponentToken($data){
        echo "abcdefghijklmnopqrstuvwxyz==================\n";
        echo var_export($data,true)."\n";
        echo "abcdefghijklmnopqrstuvwxyz==================\n";
        $obj = new Component();
        $componentVerifyTicket = $data["ComponentVerifyTicket"];
        echo "========testGetApiComponentToken====\n";
        echo $componentVerifyTicket."\n";

        echo $this->appid."\n";
        try{
            $obj->setProxy("127.0.0.1:8888");
            $result = $obj->setComponetAppid($this->appid)
                ->setComponentVerifyTicket($componentVerifyTicket)
                ->setComponetAppSecret($this->app_secret)
                ->getApiComponentToken();
            echo "=======================================\n";
            echo var_export($result)."\n";
            echo $result["component_access_token"]."\n";
//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);

            return ["component_access_token"=>$result["component_access_token"]];
        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
        }
    }

    /**
     * 获取预授权码
     * @author roc
     * @datetime:2019/12/19 17:09
     */
    public function t2estGetPreAuthCode(){
        $obj = new Component();


        echo $this->appid."\n";
        try{
            $obj->setProxy("127.0.0.1:8888");
            $result = $obj->setComponetAppid($this->appid)->setComponetAccessToken($this->componetAccessToken)
                ->getPreAuthCode();
            echo "=======================================\n";
            echo var_export($result)."\n";
//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);

        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
        }
    }

    /**
     * 使用授权码获取授权信息
     * 当用户在第三方平台授权页中完成授权流程后，第三方平台开发者可以在回调 URI 中通过 URL 参数获取授权码。
     * 使用以下接口可以换取公众号/小程序的授权信息。
     * 建议保存授权信息中的刷新令牌（authorizer_refresh_token）
     * @author roc
     * @datetime:2019/12/19 17:09
     */
    public function t2estApiQueryAuth(){
        $obj = new Component();

//        $url = "https://test.kwyapi.ke51.com/index/Y/testIndexCallBack?auth_code=&expires_in=3600";
        $auth_code = "queryauthcode@@@fj8Q0ik7agxkXuy1lvhVk-P3zOEjXfLk6LSd46Cl3F2WSMtp8k1wsEFOMXChzjNpRTkbY7buwXcWVp3lV-ANWA";
        $expires_in = "3600";
        $authorization_code = $auth_code;

        echo $this->appid."\n";
        try{
            $obj->setProxy("127.0.0.1:8888");
            $result = $obj->setComponetAppid($this->appid)->setComponetAccessToken($this->componetAccessToken)
                ->apiQueryAuth($authorization_code);
            echo "=======================================\n";
            echo var_export($result)."\n";
            $authorizer_appid = $result["authorizer_appid"];    //授权方 appid
            $authorizer_access_token = $result["authorizer_access_token"];    //接口调用令牌（在授权的公众号/小程序具备API权限时，才有此返回值）
            $expires_in = $result["expires_in"];    //authorizer_access_token的有效期（在授权的公众号/小程序具备API权限时，才有此返回值），单位：秒
            $authorizer_refresh_token = $result["authorizer_refresh_token"];    //刷新令牌（在授权的公众号具备API权限时，才有此返回值），刷新令牌主要用于第三方平台获取和刷新已授权用户的 authorizer_access_token。一旦丢失，只能让用户重新授权，才能再次拿到新的刷新令牌。用户重新授权后，之前的刷新令牌会失效
            $func_info = $result["func_info"];    //授权给开发者的权限集列表


//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);

        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
        }
    }

    /**
     * 获取授权方的帐号基本信息
     * @author roc
     * PHPUnit可以实现测试方法的依赖关系，也就是说，一个测试方法的参数的内容和是否会运行依赖于另外一个测试方法结果，依赖关系通过注释@depends来定义.这个特性一般用于检查代码的逻辑过程,一个逻辑的执行前提是另外一个逻辑的执行结果.下面来看代码例子:
     * @datetime:2019/12/20 12:15
     */
    public function t2estApiGetAuthorizerInfo(){
        $obj = new Component();

//        $url = "https://test.kwyapi.ke51.com/index/Y/testIndexCallBack?auth_code=&expires_in=3600";
        $authorizer_appid = "wx7a03580e7437b28f";
        $authorizer_appid = "wxcf8fdb66f0b906b9";

        try{
            $obj->setProxy("127.0.0.1:8888");
            $result = $obj->setComponetAppid($this->appid)
                ->setComponetAccessToken($this->componetAccessToken)
                ->apiGetAuthorizerInfo($authorizer_appid);
            echo "=======================================\n";
            echo var_export($result)."\n";


//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);
            return ["authorizer_refresh_token"=>$result["authorization_info"]["authorizer_refresh_token"]];

        }catch (WxException $wxE){
            echo "wx_error==============:".$wxE->getMessage().",file:".$wxE->getFile().",line:".$wxE->getLine().",wx_code:".$wxE->getWxErrCode()."====\n";
        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
        }
    }

    /**
     * 获取授权方的帐号基本信息
     * @author roc
     * @depends testApiGetAuthorizerInfo
     * PHPUnit可以实现测试方法的依赖关系，也就是说，一个测试方法的参数的内容和是否会运行依赖于另外一个测试方法结果，依赖关系通过注释@depends来定义.这个特性一般用于检查代码的逻辑过程,一个逻辑的执行前提是另外一个逻辑的执行结果.下面来看代码例子:
     * @param $data
     * @datetime:2019/12/20 12:15
     */
    public function t2estApiAuthorizerToken($data){
        $obj = new Component();

//        $url = "https://test.kwyapi.ke51.com/index/Y/testIndexCallBack?auth_code=&expires_in=3600";
        $authorizer_appid = "wx7a03580e7437b28f";
        $authorizer_refresh_token = $data["authorizer_refresh_token"];

        echo $authorizer_refresh_token."\n";
        try{
            $obj->setProxy("127.0.0.1:8888");
            $result = $obj->setComponetAppid($this->appid)
                ->setComponetAccessToken($this->componetAccessToken)
                ->apiAuthorizerToken($authorizer_appid,$authorizer_refresh_token);
            echo "=======================================\n";
            echo var_export($result)."\n";

            echo $result["authorizer_access_token"]."\n";

//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);

        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
        }
    }

    /**
     * 微信小程序登录
     * @author roc
     * PHPUnit可以实现测试方法的依赖关系，也就是说，一个测试方法的参数的内容和是否会运行依赖于另外一个测试方法结果，依赖关系通过注释@depends来定义.这个特性一般用于检查代码的逻辑过程,一个逻辑的执行前提是另外一个逻辑的执行结果.下面来看代码例子:
     * @datetime:2019/12/20 12:15
     */
    public function t2estLoginMiniApp(){
        $obj = new Component();

//        $url = "https://test.kwyapi.ke51.com/index/Y/testIndexCallBack?auth_code=&expires_in=3600";
        $authorizer_appid = "wx9e81798460f23253";
        $js_code = "001yqNmy1LsLnc0QUQly1Wbqmy1yqNmW";

        echo $js_code."\n";
        try{
            $obj->setProxy("127.0.0.1:8888");
            $result = $obj->setComponetAppid($this->appid)
                ->setComponetAccessToken($this->componetAccessToken)
                ->loginMiniApp($authorizer_appid,$js_code);
            echo "=======================================\n";
            echo var_export($result)."\n";


//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);

        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";
        }
    }

    /**
     * 小程序 加密数据解密算法
     * @author roc
     * PHPUnit可以实现测试方法的依赖关系，也就是说，一个测试方法的参数的内容和是否会运行依赖于另外一个测试方法结果，依赖关系通过注释@depends来定义.这个特性一般用于检查代码的逻辑过程,一个逻辑的执行前提是另外一个逻辑的执行结果.下面来看代码例子:
     * @datetime:2020/2/4 01:27
     */
    public function testDecryptData(){
        $obj = new WxBizMsgCrypt();

        $appid = 'wx4f4bc4dec97d474b';
        $sessionKey = 'tiihtNczf5v6AKRyjwEUhQ==';

        $encryptedData="CiyLU1Aw2KjvrjMdj8YKliAjtP4gsMZM
                QmRzooG2xrDcvSnxIMXFufNstNGTyaGS
                9uT5geRa0W4oTOb1WT7fJlAC+oNPdbB+
                3hVbJSRgv+4lGOETKUQz6OYStslQ142d
                NCuabNPGBzlooOmB231qMM85d2/fV6Ch
                evvXvQP8Hkue1poOFtnEtpyxVLW1zAo6
                /1Xx1COxFvrc2d7UL/lmHInNlxuacJXw
                u0fjpXfz/YqYzBIBzD6WUfTIF9GRHpOn
                /Hz7saL8xz+W//FRAUid1OksQaQx4CMs
                8LOddcQhULW4ucetDf96JcR3g0gfRK4P
                C7E/r7Z6xNrXd2UIeorGj5Ef7b1pJAYB
                6Y5anaHqZ9J6nKEBvB4DnNLIVWSgARns
                /8wR2SiRS7MNACwTyrGvt9ts8p12PKFd
                lqYTopNHR1Vf7XjfhQlVsAJdNiKdYmYV
                oKlaRv85IfVunYzO0IKXsyl7JCUjCpoG
                20f0a04COwfneQAGGwd5oa+T8yO5hzuy
                Db/XcxxmK01EpqOyuxINew==";

        $iv = 'r7BXXKkLb8qrSNn05n0qiA==';

        $obj->setAppId($appid)
            ->setKey($sessionKey)->setIv($iv);

        try{
            /**
             * InfoType字段注释：
             * component_verify_ticket
             * authorized：授权成功通知
             * unauthorized：取消授权通知
             * updateauthorized：授权更新通知
             *
             */
            /**
             * array (
            'AppId' => 'wx0f8989ab60d9588d',
            'CreateTime' => '1576822342',
            'InfoType' => 'component_verify_ticket',
            'ComponentVerifyTicket' => 'ticket@@@y2ee_3Fm5SL-gEyFElCMeuUnNGwlBflPldoG83zYvo4iQZcNaBYOvHs9hfHcLE5tztcD1pM0ntmubZXWBKYb4g',
            )

             */
            $result = $obj->decryptData($appid,$sessionKey,$encryptedData, $iv);
//            echo $result."\n";
            echo var_export($result)."\n";
//            $componentVerifyTicket = $result["ComponentVerifyTicket"];
            echo "=======================================\n";
            echo $result["ComponentVerifyTicket"]."\n";
//            $this->assertArrayHasKey($host,$host);
            $this->assertEquals($this->appid,$this->appid);
        }catch (\Exception $e){
            echo "error==============:".$e->getMessage().",file:".$e->getFile().",line:".$e->getLine()."====\n";

        }

    }

    public function t2est(){
        $auth_type = "3";
        $component_appid = "wx0f8989ab60d9588d";
        $pre_auth_code = "preauthcode@@@d2O6Ayt5YXxJmho8WT0jdq-EqCDlNib_yCzzHaTCcxmTZE9ts0Ssn6AXkz2Hvc6z";
        $redirect_uri = "https://test.kwyapi.ke51.com/index/Y/testIndexCallBack";
        $url = "https://mp.weixin.qq.com/cgi-bin/componentloginpage?component_appid={$component_appid}&pre_auth_code={$pre_auth_code}&redirect_uri={$redirect_uri}&auth_type={$auth_type}";
//        $url = "https://mp.weixin.qq.com/safe/bindcomponent?action=bindcomponent&auth_type={$auth_type}&no_scan=1&component_appid={$component_appid}&pre_auth_code={$pre_auth_code}&redirect_uri={$redirect_uri}&auth_type={$auth_type}&biz_appid=xxxx#wechat_redirect";
        echo urlencode($url);
//        echo $url;
    }
}
